import greenfoot.*;  // (World, Actor, GreenfootImage, and Greenfoot)
import java.awt.*;

/**
 * Counter that displays a number.
 * 
 * @author Michael Kolling
 * @version 1.0.1
 */
public class Counter extends Actor
{
	/** value displayed on image */
    private int value = 0;
    /** actual score */
    private int score = 0;
    private String prefix;
    private int stringLength;

    public Counter()
    {
        this("");
    }

    public Counter(String prefix)
    {
        this.prefix = prefix;
        stringLength = (prefix.length() + 2) * 16;

        setImage(new GreenfootImage(stringLength, 24));
        GreenfootImage image = getImage();
        Font font = image.getFont();
        image.setFont(font.deriveFont(24.0F));  // use larger font
        image.setColor(Color.white);
        updateImage();
    }
    
    /**
     * Act gradually updates the displayed value to match the actual score.
     */
    public void act() {
    	// immediately show correct score:
//    	if ( value != score ) {
//    		value = score;
//    		updateImage();
//    	}
    	// gradually roll to correct score
        if (value < score) {
        	if ( value < score - 10 ) value += 10;
        	else value += 2;
        	updateImage();
        }
        else if (value > score) {
        	if ( value > score + 10 ) value -= 10;
        	else value -= 2;
            updateImage();
        }
    }

    /**
     * Add an amount to the score.
     * @param amount the amount to increase score
     */
    public void add(int amount)
    {
        score += amount;
    }

    /**
     * Subtract an amount from score.
     * @param amount the amount to decease score
     */
    public void subtract(int amount)
    {
        score -= amount;
    }

    /**
     * Update the image.
     */
    private void updateImage()
    {
        GreenfootImage image = getImage();
        image.clear();
        image.drawString(prefix + value, 1, 18);
    }
}
